Ontobee

### Welcome to Ontobee!

Ontobee: A linked data server designed for ontologies. Ontobee is aimed to facilitate ontology data sharing, visualization, query, integration, and analysis. Ontobee dynamically dereferences and presents individual ontology term URIs to (i) HTML web pages for user-friendly web browsing and navigation, and to (ii) RDF source code for Semantic Web applications. Ontobee is the default linked data server for most OBO Foundry library ontologies. Ontobee has also been used for many non-OBO ontologies.

Keywords:
Jump to http://purl.obolibrary.org/obo/

Currently Ontobee has been applied for the following ontologies:

No. | Ontology Prefix | Ontology Full Name | OBO | List of Terms
--- | --- | --- | --- | ---

F: Foundry L: Library N: Not Specified/No

1 | AEO | Anatomical Entity Ontology | L |
2 | AGRO | Agronomy Ontology | L |
3 | AISM | Ontology for the Anatomy of the Insect SkeletoMuscular system (AISM) | L |
4 | AMPHX | The Amphioxus Development and Anatomy Ontology | L |
5 | APO | Ascomycete phenotype ontology | L |
6 | APOLLO_SV | Apollo Structured Vocabulary | L |
7 | ARO | Antibiotic Resistance Ontology | L |
8 | BCGO | Beta Cell Genomics Ontology | L |
9 | BCO | Biological Collections Ontology | L |
10 | BFO | Basic Formal Ontology | F |
11 | BFO11 | Basic Formal Ontology (BFO) 1.1 | L |
12 | BSPO | Biological Spatial Ontology | L |
13 | BTO | BRENDA tissue / enzyme source | L |
14 | CARO | Common Anatomy Reference Ontology | L |
15 | CDAO | Comparative Data Analysis Ontology | L |
16 | CDNO | Compositional Dietary Nutrition Ontology | L |
17 | CEPH | Cephalopod Ontology | L |
18 | CHEBI | Chemical Entities of Biological Interest | F |
19 | CHEMINF | Chemical Information Ontology | L |
20 | CHIRO | CHEBI Integrated Role Ontology | L |
21 | CHMO | Chemical Methods Ontology | L |
22 | CIDO | Coronavirus Infectious Disease Ontology | L |
23 | CIO | Confidence Information Ontology | L |
24 | CL | Cell Ontology | L |
25 | CLAO | Collembola Anatomy Ontology | L |
26 | CLO | Cell Line Ontology | L |
27 | CLO-hPSCreg | Cell Line Ontology - Human Pluripotent Stem Cell Registry | N |
28 | CLO-NICR | Cell Line Ontology - Chinese National Infrastructure of Cell Line Resource | N |
29 | CLYH | Clytia hemisphaerica Development and Anatomy Ontology | L |
30 | CMF | CranioMaxilloFacial ontology | L |
31 | CMO | Clinical measurement ontology | L |
32 | COB | Core Ontology for Biology and Biomedicine | L |
33 | CRO | Contributor Role Ontology | L |
34 | CTCAE-OAEview | OAE CTCAE view | N |
35 | CTENO | Ctenophore Ontology | L |
36 | CTO | CTO: Core Ontology of Clinical Trials | L |
37 | CVDO | Cardiovascular Disease Ontology | L |
38 | d-acts | Ontology of Document Acts | N |
39 | DDANAT | Dictyostelium discoideum anatomy | L |
40 | DDPHENO | Dictyostelium discoideum phenotype ontology | L |
41 | DIDEO | Drug-drug Interaction and Drug-drug Interaction Evidence Ontology | L |
42 | DINTO | The Drug-Drug Interactions Ontology | L |
43 | DOID | Human Disease Ontology | F |
44 | DPO | Drosophila Phenotype Ontology | L |
45 | DRON | The Drug Ontology | L |
46 | DUO | Data Use Ontology | L |
47 | ECAO | The Echinoderm Anatomy and Development Ontology | L |
48 | ECO | Evidence ontology | L |
49 | ECOCORE | An ontology of core ecological entities | L |
50 | ECTO | Environmental conditions, treatments and exposures ontology | L |
51 | EDAM | EMBRACE Data and Methods | N |
52 | EFO | Experimental Factor Ontology | N |
53 | EHDAA2 | Human developmental anatomy, abstract | L |
54 | EMAPA | Mouse Developmental Anatomy Ontology | L |
55 | ENVO | Environment Ontology | L |
56 | EPIO | Epilepsy Ontology | L |
57 | EPO | Epidemiology Ontology | L |
58 | ERO | eagle-i resource ontology | L |
59 | EUPATH | VEuPathDB ontology | L |
60 | ExO | Exposure ontology | L |
61 | FAO | Fungal gross anatomy | L |
62 | FBBI | Biological Imaging Methods Ontology | L |
63 | FBBT | Drosophila gross anatomy | L |
64 | FBCV | FlyBase Controlled Vocabulary | L |
65 | FBdv | Drosophila development | L |
66 | FIDEO | Food Interactions with Drugs Evidence Ontology | L |
67 | FIX | Physico-chemical methods and properties | L |
68 | FLOPO | Flora Phenotype Ontology | L |
69 | FMA | Foundational Model of Anatomy Ontology (subset) | L |
70 | FOBI | FOBI | L |
71 | FOODON | FOODON | L |
72 | FOVT | FuTRES Ontology of Vertebrate Traits | L |
73 | FYPO | Fission Yeast Phenotype Ontology | L |
74 | GAZ | Gazetteer | L |
75 | GECKO | Genomics Cohorts Knowledge Ontology | L |
76 | GENEPIO | Genomic Epidemiology Ontology | L |
77 | GENO | Genotype Ontology | L |
78 | GEO | Geographical Entity Ontology | L |
79 | GNO | Glycan Naming and Subsumption Ontology (GNOme) | L |
80 | GO | Gene Ontology | F |
81 | GSSO | Gender, Sex, and Sexual Orientation (GSSO) ontology | L |
82 | HANCESTRO | Human Ancestry Ontology | L |
83 | HAO | Hymenoptera Anatomy Ontology | L |
84 | HINO | Human Interaction Network Ontology | N |
85 | HOM | Homology Ontology | L |
86 | HP | Human Phenotype Ontology | L |
87 | HSAPDV | Human Developmental Stages | L |
88 | HSO | Health Surveillance Ontology | L |
89 | HTN | Hypertension Ontology | L |
90 | IAO | Information Artifact Ontology | L |
91 | IAO-Onto-Meta | IAO Ontology Metadata | N |
92 | ICDO | International Classification of Disease Ontology | N |
93 | ICEO | Integrative and Conjugative Element Ontology | L |
94 | ICO | Informed Consent Ontology | L |
95 | IDO | Infectious Disease Ontology | L |
96 | IDOBRU | Brucellosis Ontology | N |
97 | IDOMAL | Malaria Ontology | L |
98 | INO | Interaction Network Ontology | L |
99 | KISAO | Kinetic Simulation Algorithm Ontology | L |
100 | KTAO | Kidney Tissue Atlas Ontology | N |
101 | LABO | clinical LABoratory Ontology | L |
102 | LINCS-CLOview | CLO LINCS view | N |
103 | LTHIDO | LTHIDO | N |
104 | MA | Mouse adult gross anatomy | L |
105 | MAMO | Mathematical modeling ontology | L |
106 | MAXO | Medical Action Ontology | L |
107 | MCO | Microbial Conditions Ontology | L |
108 | MF | Mental Functioning Ontology | L |
109 | MFMO | Mammalian Feeding Muscle Ontology | L |
110 | MFOEM | Emotion Ontology | L |
111 | MFOMD | Mental Disease Ontology | L |
112 | MI | Molecular Interactions Controlled Vocabulary | L |
113 | MIAPA | MIAPA Ontology | L |
114 | MicrO | Ontology of Prokaryotic Phenotypic and Metabolic Characters | L |
115 | miRNAO | microRNA Ontology | L |
116 | MIRO | Mosquito insecticide resistance | L |
117 | MMO | Measurement method ontology | L |
118 | MMUSDV | Mouse Developmental Stages | L |
119 | MOD | Protein modification | L |
120 | MONDO | Mondo Disease Ontology | L |
121 | MOP | Molecular Process Ontology | L |
122 | MP | Mammalian Phenotype Ontology | L |
123 | MPATH | Mouse pathology | N |
124 | MPIO | Minimum PDDI Information Ontology | L |
125 | MRO | MHC Restriction Ontology | L |
126 | MS | Mass spectrometry ontology | L |
127 | NBO | Neuro Behavior Ontology | L |
128 | NCBITaxon | NCBI organismal classification | L |
129 | NCIT | NCI Thesaurus OBO Edition | L |
130 | NCRO | Non-Coding RNA Ontology | L |
131 | NDF-RT | National Drug File Reference Terminology | N |
132 | NFO | NFO | N |
133 | NOMEN | NOMEN - A nomenclatural ontology for biological names | L |
134 | OAE | Ontology of Adverse Events | L |
135 | OARCS | Ontology of Arthropod Circulatory Systems | L |
136 | OBA | Ontology of Biological Attributes | L |
137 | OBCS | Ontology of Biological and Clinical Statistics | L |
138 | OBI | Ontology for Biomedical Investigations | F |
139 | OBI-NIAID-GSC-BRC-view | OBI NIAID-GSC-BRC view | N |
140 | OBIB | Ontology for Biobanking | L |
141 | OBIws | OBI web service, development version | N |
142 | OCE | Ontology of Chemical Elements | N |
143 | OCMR | Ontology of Chinese Medicine for Rheumatism | N |
144 | OCVDAE | Ontology of Cardiovascular Drug Adverse Events | N |
145 | ODAE | Ontology of Drug Adverse Events | N |
146 | ODNAE | Ontologyof Drug Neuropathy Adverse Events | N |
147 | OGG | The Ontology of Genes and Genomes | L |
148 | OGG-At | Ontology of Genes and Genomes - Arabidopsis thaliana | N |
149 | OGG-Bru | Ontology of Genes and Genomes - Brucella | N |
150 | OGG-Ce | Ontology of Genes and Genomes - Caenorhabditis elegans | N |
151 | OGG-Dm | Ontology of Genes and Genomes - Fruit Fly | N |
152 | OGG-Dr | Ontology of Genes and Genomes - Zebrafish | N |
153 | OGG-Mm | Ontology of Genes and Genomes - Mouse | N |
154 | OGG-Pf | Ontology of Genes and Genomes - Plasmodium falciparum | N |
155 | OGG-Sc | Ontology of Genes and Genomes - Yeast | N |
156 | OGI | Ontology for genetic interval | L |
157 | OGMS | Ontology for General Medical Science | L |
158 | OGSF | Ontology of Genetic Susceptibility Factor | L |
159 | OHD | The Oral Health and Disease Ontology | L |
160 | OHMI | Ontology of Host-Microbiome Interactions | L |
161 | OHPI | Ontology of Host Pathogen Interactions | L |
162 | OLATDV | Medaka Developmental Stages | L |
163 | OLOBO | Ontology for Linking Biological and Medical Ontologies | N |
164 | OMIABIS | Ontologized MIABIS | L |
165 | OMIT | Ontology for MIRNA Target | L |
166 | OMO | OBO Metadata Ontology | L |
167 | OMP | Ontology of Microbial Phenotypes | L |
168 | OMRSE | Ontology of Medically Related Social Entities | L |
169 | ONE | Ontology for Nutritional Epidemiology | L |
170 | ONS | Ontology for Nutritional Studies | L |
171 | ONTOAVIDA | ontoavida | n |
172 | ONTONEO | Obstetric and Neonatal Ontology | L |
173 | OOSTT | Ontology of Organizational Structures of Trauma centers and Trauma systems | L |
174 | OPL | Ontology for Parasite LifeCycle | L |
175 | OPMI | Ontology of Precision Medicine and Investigation | L |
176 | ORNASEQ | Ontology of RNA Sequencing | L |
177 | OSCI | Ontology for Stem Cell Investigations | N |
178 | OVAE | Ontology of Vaccine Adverse Events | L |
179 | PATO | Phenotype And Trait Ontology | F |
180 | PCO | Population and Community Ontology | L |
181 | PDRO | The Prescription of Drugs Ontology | L |
182 | PDUMDV | Platynereis Developmental Stages | L |
183 | PECO | Plant Experimental Conditions Ontology | L |
184 | PHIPO | Pathogen Host Interaction Phenotype Ontology | L |
185 | PLANA | planaria-ontology | L |
186 | PLANP | Planarian Phenotype Ontology | L |
187 | PNO | Proper Name Ontology | N |
188 | PO | Plant Ontology | F |
189 | PORO | Porifera Ontology | L |
190 | PPO | Plant Phenology Ontology | L |
191 | PR | PRotein Ontology (PRO) | F |
192 | PSDO | Performance Summary Display Ontology | L |
193 | PSO | Plant Stress Ontology | L |
194 | PW | Pathway ontology | L |
195 | RBO | Radiation Biology Ontology | L |
196 | REO | Reagent Ontology | N |
197 | REX | Physico-chemical process | L |
198 | RNAO | RNA ontology | L |
199 | RO | Relation Ontology | L |
200 | RS | Rat Strain Ontology | L |
201 | RXNO | Name Reaction Ontology | L |
202 | SBO | Systems Biology Ontology | L |
203 | SCDO | Sickle Cell Disease Ontology | L |
204 | SDGIO | Sustainable Development Goals Interface Ontology | N |
205 | SEPIO | Scientific Evidence and Provenance Information Ontology | L |
206 | SIBO | Social Insect Behavior Ontology | L |
207 | SIO | Semanticscience Integrated Ontology | N |
208 | SO | Sequence types and features ontology | L |
209 | SPD | Spider Ontology | L |
210 | STATO | The Statistical Methods Ontology | L |
211 | SWO | Software ontology | L |
212 | SYMP | Symptom Ontology | L |
213 | TADS | Tick Anatomy Ontology | L |
214 | TAXRANK | Taxonomic rank vocabulary | L |
215 | TGMA | Mosquito gross anatomy ontology | L |
216 | TO | Plant Trait Ontology | L |
217 | TRANS | Pathogen Transmission Ontology | L |
218 | TSO | Transportation System Ontology | N |
219 | TTO | Teleost taxonomy ontology | L |
220 | TXPO | Toxic Process Ontology | L |
221 | UBERON | Uberon multi-species anatomy ontology | L |
222 | uberon-basic | Uber anatomy ontology, basic version | N |
223 | uberon_depictions | uberon_depictions | N |
224 | UO | Units of measurement ontology | L |
225 | UPA | Unipathway | L |
226 | UPHENO | Unified phenotype ontology (uPheno) | L |
227 | VariO | Variation Ontology | L |
228 | VICO | Vaccination Informed Consent Ontology | N |
229 | VIO | Vaccine Investigation Ontology | N |
230 | VIVO-ISF | VIVO-ISF | N |
231 | VO | Vaccine Ontology | L |
232 | VT | Vertebrate trait ontology | L |
233 | VTO | Vertebrate Taxonomy Ontology | L |
234 | WBbt | C. elegans Gross Anatomy Ontology | L |
235 | WBLS | C. elegans development ontology | L |
236 | WBPhenotype | C. elegans phenotype | L |
237 | XAO | Xenopus Anatomy Ontology | F |
238 | XCO | Experimental condition ontology | L |
239 | XL | Cross-linker reagents ontology | L |
240 | XLMOD | HUPO-PSI cross-linking and derivatization reagents controlled vocabulary | L |
241 | XPO | Xenopus Phenotype Ontology | L |
242 | ZECO | Zebrafish Experimental Conditions Ontology | L |
243 | ZFA | Zebrafish anatomy and development ontology | F |
244 | ZFS | Zebrafish developmental stages ontology | L |
245 | ZP | Zebrafish Phenotype Ontology | L |

Please cite the following reference for Ontobee:

Ong E, Xiang Z, Zhao B, Liu Y, Lin Y, Zheng J, Mungall C, Courtot M, Ruttenberg A, He Y. Ontobee: A linked ontology data server to support ontology term dereferencing, linkage, query, and integration. Nucleic Acid Research. 2017 Jan 4;45(D1):D347-D352. PMID: 27733503. PMCID: PMC5210626.

Ontobee ICBO proceeding paper:

Xiang Z, Mungall C, Ruttenberg A, He Y. Ontobee: A Linked Data Server and Browser for Ontology Terms. Proceedings of the 2nd International Conference on Biomedical Ontologies (ICBO), July 28-30, 2011, Buffalo, NY, USA. Pages 279-281. URL: http://ceur-ws.org/Vol-833/paper48.pdf.